@@ -29,8 +29,8 @@ from sxm_discord.utils import (
     send_message,
 )
 
-from .checks import is_playing, no_pm, require_matching_voice, require_voice
-from .converters import CountConverter, VolumeConverter
+from .checks import is_playing, no_pm, require_voice
+from .converters import CountConverter
 from .models import (
     ArchivedSongCarousel,
     ReactionCarousel,
@@ -176,7 +176,7 @@ class DiscordWorker(
             f"{len(self._state.channels)} channels available"
         )
 
-    async def event_loop(self):
+    async def _event_loop(self):
         while not self.shutdown_event.is_set():
             was_connected = self._state.sxm_running
 
@@ -210,6 +210,12 @@ class DiscordWorker(
 
             await asyncio.sleep(0.1)
 
+    async def event_loop(self):
+        try:
+            await self._event_loop()
+        except Exception:
+            self._log.exception("Error doing event loop!")
+
     async def create_carousel(self, ctx: SlashContext, carousel: ReactionCarousel):
         await carousel.update(self._state, ctx)
 
@@ -484,38 +490,6 @@ class DiscordWorker(
             ctx, f"Successfully joined {ctx.author.voice.channel.mention}"
         )
 
-    @cog_ext.cog_subcommand(
-        base=get_root_command(),
-        options=[
-            create_option(
-                name="amount",
-                description="Volume Level (1-100)",
-                option_type=4,
-                required=False,
-            )
-        ],
-    )
-    async def volume(self, ctx: SlashContext, amount: Optional[int] = None) -> None:
-        """Changes the volume of music"""
-
-        if not await no_pm(ctx) or not await require_matching_voice(ctx):
-            return
-
-        try:
-            amount_percent = await VolumeConverter().convert(ctx, amount)
-        except BadArgument as e:
-            await send_message(ctx, str(e))
-            return
-
-        if amount_percent is None:
-            await send_message(
-                ctx, f"Volume is currently {int(self.player.volume * 100)}%"
-            )
-            return
-
-        self.player.volume = amount_percent
-        await send_message(ctx, f"Set volume to {int(self.player.volume * 100)}%")
-
 
 class DiscordArchivedWorker(
     SXMArchivedCommands,
